<?php
/**
 * Routes configuration
 *
 * In this file, you set up routes to your controllers and their actions.
 * Routes are very important mechanism that allows you to freely connect
 * different URLs to chosen controllers and their actions (functions).
 *
 * CakePHP(tm) : Rapid Development Framework (http://cakephp.org)
 * Copyright (c) Cake Software Foundation, Inc. (http://cakefoundation.org)
 *
 * Licensed under The MIT License
 * For full copyright and license information, please see the LICENSE.txt
 * Redistributions of files must retain the above copyright notice.
 *
 * @copyright     Copyright (c) Cake Software Foundation, Inc. (http://cakefoundation.org)
 * @link          http://cakephp.org CakePHP(tm) Project
 * @license       http://www.opensource.org/licenses/mit-license.php MIT License
 */

use Cake\Core\Plugin;
use Cake\Routing\Router;

/**
 * The default class to use for all routes
 *
 * The following route classes are supplied with CakePHP and are appropriate
 * to set as the default:
 *
 * - Route
 * - InflectedRoute
 * - DashedRoute
 *
 * If no call is made to `Router::defaultRouteClass()`, the class used is
 * `Route` (`Cake\Routing\Route\Route`)
 *
 * Note that `Route` does not do any inflections on URLs which will result in
 * inconsistently cased URLs when used with `:plugin`, `:controller` and
 * `:action` markers.
 *
 */
Router::defaultRouteClass('DashedRoute');

Router::scope('/', function ($routes) {
    /**
     * Here, we are connecting '/' (base path) to a controller called 'Pages',
     * its action called 'display', and we pass a param to select the view file
     * to use (in this case, src/Template/Pages/home.ctp)...
     */

	$routes->connect('/', ['controller' => 'Users', 'action' => 'login']);

	$routes->connect('/:section/sub/:category', 
		[
			'controller' => 'SubMenu', 
			'action' => 'index'
		],
		[
			'pass' => ['section','category']
		]);
	
	$routes->connect('/gallery/albums', 
		[
			'controller' => 'Albums',
			'action'=>'index'
		]);
	
	$routes->connect('/gallery/albums/add', 
		[
			'controller' => 'Albums',
			'action'=>'add'
		]);
	
	$routes->connect('/gallery/albums/all', 
		[
			'controller' => 'Albums',
			'action'=>'index'
		]);
	
	$routes->connect('/gallery/albums/edit/:id', 
		[
			'controller' => 'Albums',
			'action'=>'edit'
		],
		[
			'pass' => ['id']
		]);
	
	 $routes->connect('/gallery/albums/:action/:id', 
		[
			'controller' => 'Albums',
			'action'=>'edit'
		],
		[
			'pass' => ['id']
		]);
	
	$routes->connect('/about-us/sub/:section/:action/**', ['controller' => 'AboutUsMenu'],
		   [
				'pass' => ['section']
			]

	);  


	$routes->connect('/:section/sub/:category/:action/**', ['controller' => 'SubMenu'],
		   [
				'pass' => ['section','category']
			]

	); 

	$routes->connect('/:section/add-sub-menu/:id', ['controller' => 'Menus', 'action' => 'addSubMenu'],
		   [
				'pass' => ['section','id']
			]

	);
	$routes->connect('/:section/edit-sub-menu/:id', ['controller' => 'Menus', 'action' => 'editSubMenu'],
		   [
				'pass' => ['section','id']
			]

	);

	$routes->connect('/:section/edit-sub-sub-menu/:id', ['controller' => 'Menus', 'action' => 'editSubSubMenu'],
		   [
				'pass' => ['section','id']
			]

	);
	$routes->connect('/:section/sub-menus/:id', ['controller' => 'Menus', 'action' => 'subMenus'],
		   [
				'pass' => ['section','id']
			]

	); 

	$routes->connect('/:section/add-sub-sub-menu/:id', ['controller' => 'Menus', 'action' => 'addSubSubMenu'],
		   [
				'pass' => ['section','id']
			]

	); 

	$routes->connect('/:section/sub-sub-menus/:id', ['controller' => 'Menus', 'action' => 'subSubMenus'],
		   [
				'pass' => ['section','id']
			]

	);

	$routes->connect('/:section/disable-menu/:id', ['controller' => 'Menus', 'action' => 'disableMenu'],
		   [
				'pass' => ['section','id']
			]

	);   
	$routes->connect('/:section/enable-menu/:id', ['controller' => 'Menus', 'action' => 'enableMenu'],
		   [
				'pass' => ['section','id']
			]

	);   



	$routes->connect('/products/sub/product-categories', ['controller' => 'Categories', 'action' => 'viewAllCategories'],
		   [
				'pass' => ['section']
			]

	); 

	$routes->connect('/products/sub/product-categories/:action', ['controller' => 'Categories'],
		   [
				'pass' => []
			]

	); 
	$routes->connect('/products/sub/product-categories/:action/:id', ['controller' => 'Categories'],
		   [
				'pass' => ['id']
			]

	); 
	$routes->connect('/products/sub/product-categories/:action/:pid/:id', ['controller' => 'Categories'],
		   [
				'pass' => ['pid','id']
			]

	); 

	$routes->connect('/products/sub/:section', ['controller' => 'AboutUsMenu', 'action' => 'index'],
		   [
				'pass' => ['section']
			]

	);
	
    /**
	 * Set routes for standard controllers already defined for specific sections
	 * from the matching the route
	 * Basic contents supports
	 * 1. Listing (All, Pending, Enable, Disable, Edited)
	 * 2. Add new item
	 * 3. Edit item
	 * 4. Enable item
	 * 5. Disable item
	 */
	// Section: Home
    $routes->connect('/home',
		[
			'controller' => 'Home',
		]);
	
	/**
	 * This route should have been taken care of from :section menu above
	 * but some home it doesnt execute the routes sequentially, it seems to have
	 * priority levels with the construction before top down sequence.
	 * So recreate the menu routes for each section with a controller created for it
	 */
    $routes->connect('/home/add-sub-menu/:id',
		[
			'controller' => 'Menus',
			'action' => 'addSubMenu',
			'section' => 'home'
		],
		[
			'pass' => ['section', 'id']
		]);
	
	$routes->connect('/home/edit-sub-menu/:id',
		[
			'controller' => 'Menus', 
			'action' => 'editSubMenu',
			'section' => 'home'
		],
		[
			'pass' => ['section','id']
		]);

	$routes->connect('/home/edit-sub-sub-menu/:id',
		[
			'controller' => 'Menus', 
			'action' => 'editSubSubMenu',
			'section' => 'home'
		],
		[
			'pass' => ['section','id']
		]);
	
	$routes->connect('/home/sub-menus/:id', 
		[
			'controller' => 'Menus', 
			'action' => 'subMenus',
			'section' => 'home'
		],
		[
			'pass' => ['section','id']
		]);

	$routes->connect('/home/add-sub-sub-menu/:id', 
		[
			'controller' => 'Menus', 
			'action' => 'addSubSubMenu',
			'section' => 'home'
		],
		[
			'pass' => ['section','id']
		]);

	$routes->connect('/home/sub-sub-menus/:id', 
		[
			'controller' => 'Menus', 
			'action' => 'subSubMenus',
			'section' => 'home'
		],
		[
			'pass' => ['section','id']
		]);

	$routes->connect('/home/disable-menu/:id', 
		[
			'controller' => 'Menus', 
			'action' => 'disableMenu',
			'section' => 'home'
		],
		[
			'pass' => ['section','id']
		]);
	
	$routes->connect('/home/enable-menu/:id', 
		[
			'controller' => 'Menus', 
			'action' => 'enableMenu',
			'section' => 'home'
		],
		[
			'pass' => ['section','id']
		]);   
	/** Menu re rounting End here **/
	
    $routes->connect('/home/:action',
		[
			'controller' => 'Home',
		]);
	
    $routes->connect('/home/:action/:id',
		[
			'controller' => 'Home',
		],
        [
            'pass' => ['id']
        ]);
	
    $routes->connect('/home/:action/:id/:cid',
		[
			'controller' => 'Home',
		],
        [
            'pass' => ['id', 'cid']
        ]); 
	
    /**
	 * Set routes for standard controllers already defined for specific sections
	 * from the matching the route
	 * Basic contents supports
	 * 1. Listing (All, Pending, Enable, Disable, Edited)
	 * 2. Add new item
	 * 3. Edit item
	 * 4. Enable item
	 * 5. Disable item
	 */
	// Section: AboutUs
    $routes->connect('/about-us',
		[
			'controller' => 'AboutUs',
		]);
	
	/**
	 * This route should have been taken care of from :section menu above
	 * but some home it doesnt execute the routes sequentially, it seems to have
	 * priority levels with the construction before top down sequence.
	 * So recreate the menu routes for each section with a controller created for it
	 */
    $routes->connect('/about-us/add-sub-menu/:id',
		[
			'controller' => 'Menus',
			'action' => 'addSubMenu',
			'section' => 'about-us'
		],
		[
			'pass' => ['section', 'id']
		]);
	
	$routes->connect('/about-us/edit-sub-menu/:id',
		[
			'controller' => 'Menus', 
			'action' => 'editSubMenu',
			'section' => 'about-us'
		],
		[
			'pass' => ['section','id']
		]);

	$routes->connect('/about-us/edit-sub-sub-menu/:id',
		[
			'controller' => 'Menus', 
			'action' => 'editSubSubMenu',
			'section' => 'about-us'
		],
		[
			'pass' => ['section','id']
		]);
	
	$routes->connect('/about-us/sub-menus/:id', 
		[
			'controller' => 'Menus', 
			'action' => 'subMenus',
			'section' => 'about-us'
		],
		[
			'pass' => ['section','id']
		]);

	$routes->connect('/about-us/add-sub-sub-menu/:id', 
		[
			'controller' => 'Menus', 
			'action' => 'addSubSubMenu',
			'section' => 'about-us'
		],
		[
			'pass' => ['section','id']
		]);

	$routes->connect('/about-us/sub-sub-menus/:id', 
		[
			'controller' => 'Menus', 
			'action' => 'subSubMenus',
			'section' => 'about-us'
		],
		[
			'pass' => ['section','id']
		]);

	$routes->connect('/about-us/disable-menu/:id', 
		[
			'controller' => 'Menus', 
			'action' => 'disableMenu',
			'section' => 'about-us'
		],
		[
			'pass' => ['section','id']
		]);
	
	$routes->connect('/about-us/enable-menu/:id', 
		[
			'controller' => 'Menus', 
			'action' => 'enableMenu',
			'section' => 'about-us'
		],
		[
			'pass' => ['section','id']
		]);   
	/** Menu re rounting End here **/
	
    $routes->connect('/about-us/:action',
		[
			'controller' => 'AboutUs',
		]);
	
    $routes->connect('/about-us/:action/:id',
		[
			'controller' => 'AboutUs',
		],
        [
            'pass' => ['id']
        ]);
	
    $routes->connect('/about-us/:action/:id/:cid',
		[
			'controller' => 'AboutUs',
		],
        [
            'pass' => ['id', 'cid']
        ]); 
	
    /**
	 * Set routes for standard controllers already defined for specific sections
	 * from the matching the route
	 * Basic contents supports
	 * 1. Listing (All, Pending, Enable, Disable, Edited)
	 * 2. Add new item
	 * 3. Edit item
	 * 4. Enable item
	 * 5. Disable item
	 */
	// Section: Services
    $routes->connect('/services',
		[
			'controller' => 'Services',
		]);
	
	/**
	 * This route should have been taken care of from :section menu above
	 * but some home it doesnt execute the routes sequentially, it seems to have
	 * priority levels with the construction before top down sequence.
	 * So recreate the menu routes for each section with a controller created for it
	 */
    $routes->connect('/services/add-sub-menu/:id',
		[
			'controller' => 'Menus',
			'action' => 'addSubMenu',
			'section' => 'services'
		],
		[
			'pass' => ['section', 'id']
		]);
	
	$routes->connect('/services/edit-sub-menu/:id',
		[
			'controller' => 'Menus', 
			'action' => 'editSubMenu',
			'section' => 'services'
		],
		[
			'pass' => ['section','id']
		]);

	$routes->connect('/services/edit-sub-sub-menu/:id',
		[
			'controller' => 'Menus', 
			'action' => 'editSubSubMenu',
			'section' => 'services'
		],
		[
			'pass' => ['section','id']
		]);
	
	$routes->connect('/services/sub-menus/:id', 
		[
			'controller' => 'Menus', 
			'action' => 'subMenus',
			'section' => 'services'
		],
		[
			'pass' => ['section','id']
		]);

	$routes->connect('/services/add-sub-sub-menu/:id', 
		[
			'controller' => 'Menus', 
			'action' => 'addSubSubMenu',
			'section' => 'services'
		],
		[
			'pass' => ['section','id']
		]);

	$routes->connect('/services/sub-sub-menus/:id', 
		[
			'controller' => 'Menus', 
			'action' => 'subSubMenus',
			'section' => 'services'
		],
		[
			'pass' => ['services','id']
		]);

	$routes->connect('/services/disable-menu/:id', 
		[
			'controller' => 'Menus', 
			'action' => 'disableMenu',
			'section' => 'services'
		],
		[
			'pass' => ['section','id']
		]);
	
	$routes->connect('/services/enable-menu/:id', 
		[
			'controller' => 'Menus', 
			'action' => 'enableMenu',
			'section' => 'services'
		],
		[
			'pass' => ['section','id']
		]);   
	/** Menu re rounting End here **/
	
    $routes->connect('/services/:action',
		[
			'controller' => 'Services',
		]);
	
    $routes->connect('/services/:action/:id',
		[
			'controller' => 'Services',
		],
        [
            'pass' => ['id']
        ]);
	
    $routes->connect('/services/:action/:id/:cid',
		[
			'controller' => 'Services',
		],
        [
            'pass' => ['id', 'cid']
        ]); 
	
    /**
	 * Set routes for standard controllers already defined for specific sections
	 * from the matching the route
	 * Basic contents supports
	 * 1. Listing (All, Pending, Enable, Disable, Edited)
	 * 2. Add new item
	 * 3. Edit item
	 * 4. Enable item
	 * 5. Disable item
	 */
	// Section: ContactUs
    $routes->connect('/contact-us',
		[
			'controller' => 'ContactUs',
		]);
	
	/**
	 * This route should have been taken care of from :section menu above
	 * but some home it doesnt execute the routes sequentially, it seems to have
	 * priority levels with the construction before top down sequence.
	 * So recreate the menu routes for each section with a controller created for it
	 */
    $routes->connect('/contact-us/add-sub-menu/:id',
		[
			'controller' => 'Menus',
			'action' => 'addSubMenu',
			'section' => 'contact-us'
		],
		[
			'pass' => ['section', 'id']
		]);
	
	$routes->connect('/contact-us/edit-sub-menu/:id',
		[
			'controller' => 'Menus', 
			'action' => 'editSubMenu',
			'section' => 'contact-us'
		],
		[
			'pass' => ['section','id']
		]);

	$routes->connect('/contact-us/edit-sub-sub-menu/:id',
		[
			'controller' => 'Menus', 
			'action' => 'editSubSubMenu',
			'section' => 'contact-us'
		],
		[
			'pass' => ['section','id']
		]);
	
	$routes->connect('/contact-us/sub-menus/:id', 
		[
			'controller' => 'Menus', 
			'action' => 'subMenus',
			'section' => 'contact-us'
		],
		[
			'pass' => ['section','id']
		]);

	$routes->connect('/contact-us/add-sub-sub-menu/:id', 
		[
			'controller' => 'Menus', 
			'action' => 'addSubSubMenu',
			'section' => 'contact-us'
		],
		[
			'pass' => ['section','id']
		]);

	$routes->connect('/contact-us/sub-sub-menus/:id', 
		[
			'controller' => 'Menus', 
			'action' => 'subSubMenus',
			'section' => 'contact-us'
		],
		[
			'pass' => ['section','id']
		]);

	$routes->connect('/contact-us/disable-menu/:id', 
		[
			'controller' => 'Menus', 
			'action' => 'disableMenu',
			'section' => 'contact-us'
		],
		[
			'pass' => ['section','id']
		]);
	
	$routes->connect('/contact-us/enable-menu/:id', 
		[
			'controller' => 'Menus', 
			'action' => 'enableMenu',
			'section' => 'contact-us'
		],
		[
			'pass' => ['section','id']
		]);   
	/** Menu re rounting End here **/
	
    $routes->connect('/contact-us/:action',
		[
			'controller' => 'ContactUs',
		]);
	
    $routes->connect('/contact-us/:action/:id',
		[
			'controller' => 'ContactUs',
		],
        [
            'pass' => ['id']
        ]);
	
    $routes->connect('/contact-us/:action/:id/:cid',
		[
			'controller' => 'ContactUs',
		],
        [
            'pass' => ['id', 'cid']
        ]); 
	
    /**
	 * Set routes for standard controllers already defined for specific sections
	 * from the matching the route
	 * Basic contents supports
	 * 1. Listing (All, Pending, Enable, Disable, Edited)
	 * 2. Add new item
	 * 3. Edit item
	 * 4. Enable item
	 * 5. Disable item
	 */
	// Section: Banners
    $routes->connect('/banners',
		[
			'controller' => 'Banners',
		]);
	
    $routes->connect('/banners/:action',
		[
			'controller' => 'Banners',
		]);
	
    $routes->connect('/banners/:action/:id',
		[
			'controller' => 'Banners',
		],
        [
            'pass' => ['id']
        ]);
	
    $routes->connect('/banners/:action/:id/:cid',
		[
			'controller' => 'Banners',
		],
        [
            'pass' => ['id', 'cid']
        ]);
	
    /**
	 * Set routes for Files uploading controllers
	 * from the matching the route
	 * Basic contents supports
	 * 1. Listing (All, Pending, Enable, Disable, Edited)
	 * 2. Add new item
	 * 3. Edit item
	 * 4. Enable item
	 * 5. Disable item
	 */
	// Section: File Uploads
    $routes->connect('/file-uploads',
		[
			'controller' => 'FileUploads',
		]);
	
    $routes->connect('/file-uploads/:action',
		[
			'controller' => 'FileUploads',
		]);
	
    $routes->connect('/file-uploads/:action/:id',
		[
			'controller' => 'FileUploads',
		],
        [
            'pass' => ['id']
        ]);
	
    $routes->connect('/file-uploads/:action/:id/:cid',
		[
			'controller' => 'FileUploads',
		],
        [
            'pass' => ['id', 'cid']
        ]);
	
    /**
	 * Set routes for standard controllers already defined for specific sections
	 * from the matching the route
	 * Basic contents supports
	 * 1. Listing (All, Pending, Enable, Disable, Edited)
	 * 2. Add new item
	 * 3. Edit item
	 * 4. Enable item
	 * 5. Disable item
	 */
	// Section: Gallery
    $routes->connect('/gallery',
		[
			'controller' => 'Gallery',
		]);
	
    $routes->connect('/gallery/:action',
		[
			'controller' => 'Gallery',
		]);
	
    $routes->connect('/gallery/:action/:id',
		[
			'controller' => 'Gallery',
		],
        [
            'pass' => ['id']
        ]);
	
    $routes->connect('/gallery/:action/:id/:cid',
		[
			'controller' => 'Gallery',
		],
        [
            'pass' => ['id', 'cid']
        ]);  
	
    /**
	 * Set routes for standard controllers already defined for specific sections
	 * from the matching the route
	 * Basic contents supports
	 * 1. Listing (All, Pending, Enable, Disable, Edited)
	 * 2. Add new item
	 * 3. Edit item
	 * 4. Enable item
	 * 5. Disable item
	 */
	// Section: Rooms
    $routes->connect('/rooms',
		[
			'controller' => 'Rooms',
		]);
	
	/**
	 * This route should have been taken care of from :section menu above
	 * but some home it doesnt execute the routes sequentially, it seems to have
	 * priority levels with the construction before top down sequence.
	 * So recreate the menu routes for each section with a controller created for it
	 */
    $routes->connect('/rooms/add-sub-menu/:id',
		[
			'controller' => 'Menus',
			'action' => 'addSubMenu',
			'section' => 'rooms'
		],
		[
			'pass' => ['section', 'id']
		]);
	
	$routes->connect('/rooms/edit-sub-menu/:id',
		[
			'controller' => 'Menus', 
			'action' => 'editSubMenu',
			'section' => 'rooms'
		],
		[
			'pass' => ['section','id']
		]);

	$routes->connect('/rooms/edit-sub-sub-menu/:id',
		[
			'controller' => 'Menus', 
			'action' => 'editSubSubMenu',
			'section' => 'rooms'
		],
		[
			'pass' => ['section','id']
		]);
	
	$routes->connect('/rooms/sub-menus/:id', 
		[
			'controller' => 'Menus', 
			'action' => 'subMenus',
			'section' => 'rooms'
		],
		[
			'pass' => ['section','id']
		]);

	$routes->connect('/rooms/add-sub-sub-menu/:id', 
		[
			'controller' => 'Menus', 
			'action' => 'addSubSubMenu',
			'section' => 'rooms'
		],
		[
			'pass' => ['section','id']
		]);

	$routes->connect('/rooms/sub-sub-menus/:id', 
		[
			'controller' => 'Menus', 
			'action' => 'subSubMenus',
			'section' => 'rooms'
		],
		[
			'pass' => ['section','id']
		]);

	$routes->connect('/rooms/disable-menu/:id', 
		[
			'controller' => 'Menus', 
			'action' => 'disableMenu',
			'section' => 'rooms'
		],
		[
			'pass' => ['section','id']
		]);
	
	$routes->connect('/rooms/enable-menu/:id', 
		[
			'controller' => 'Menus', 
			'action' => 'enableMenu',
			'section' => 'rooms'
		],
		[
			'pass' => ['section','id']
		]);   
	/** Menu re rounting End here **/
	
    $routes->connect('/rooms/:action',
		[
			'controller' => 'Rooms',
		]);
	
    $routes->connect('/rooms/:action/:id',
		[
			'controller' => 'Rooms',
		],
        [
            'pass' => ['id']
        ]);
	
    $routes->connect('/rooms/:action/:id/:cid',
		[
			'controller' => 'Rooms',
		],
        [
            'pass' => ['id', 'cid']
        ]); 
	
    /**
	 * Set routes for standard controllers already defined for specific sections
	 * from the matching the route
	 * Basic contents supports
	 * 1. Listing (All, Pending, Enable, Disable, Edited)
	 * 2. Add new item
	 * 3. Edit item
	 * 4. Enable item
	 * 5. Disable item
	 */
	// Section: Rooms
    $routes->connect('/products',
		[
			'controller' => 'Products',
		]);
	
	/**
	 * This route should have been taken care of from :section menu above
	 * but some home it doesnt execute the routes sequentially, it seems to have
	 * priority levels with the construction before top down sequence.
	 * So recreate the menu routes for each section with a controller created for it
	 */
    $routes->connect('/products/add-sub-menu/:id',
		[
			'controller' => 'Menus',
			'action' => 'addSubMenu',
			'section' => 'products'
		],
		[
			'pass' => ['section', 'id']
		]);
	
	$routes->connect('/products/edit-sub-menu/:id',
		[
			'controller' => 'Menus', 
			'action' => 'editSubMenu',
			'section' => 'products'
		],
		[
			'pass' => ['section','id']
		]);

	$routes->connect('/products/edit-sub-sub-menu/:id',
		[
			'controller' => 'Menus', 
			'action' => 'editSubSubMenu',
			'section' => 'products'
		],
		[
			'pass' => ['section','id']
		]);
	
	$routes->connect('/products/sub-menus/:id', 
		[
			'controller' => 'Menus', 
			'action' => 'subMenus',
			'section' => 'products'
		],
		[
			'pass' => ['section','id']
		]);

	$routes->connect('/products/add-sub-sub-menu/:id', 
		[
			'controller' => 'Menus', 
			'action' => 'addSubSubMenu',
			'section' => 'products'
		],
		[
			'pass' => ['section','id']
		]);

	$routes->connect('/products/sub-sub-menus/:id', 
		[
			'controller' => 'Menus', 
			'action' => 'subSubMenus',
			'section' => 'products'
		],
		[
			'pass' => ['section','id']
		]);

	$routes->connect('/products/disable-menu/:id', 
		[
			'controller' => 'Menus', 
			'action' => 'disableMenu',
			'section' => 'products'
		],
		[
			'pass' => ['section','id']
		]);
	
	$routes->connect('/products/enable-menu/:id', 
		[
			'controller' => 'Menus', 
			'action' => 'enableMenu',
			'section' => 'products'
		],
		[
			'pass' => ['section','id']
		]);   
	/** Menu re rounting End here **/
	
    $routes->connect('/products/:action',
		[
			'controller' => 'Products',
		]);
	
    $routes->connect('/products/:action/:id',
		[
			'controller' => 'Products',
		],
        [
            'pass' => ['id']
        ]);
	
    $routes->connect('/products/:action/:id/:cid',
		[
			'controller' => 'Products',
		],
        [
            'pass' => ['id', 'cid']
        ]); 
	
	// Fallback routes for the base content. to render menus without controllers and templates
	
    /**
	 * Set the fallback controller to BaseContents, when no matching controller is found
	 * from the matching the route
	 * Basic contents supports
	 * 1. Listing (All, Pending, Enable, Disable, Edited)
	 * 2. Add new item
	 * 3. Edit item
	 * 4. Enable item
	 * 5. Disable item
	 */
    $routes->connect('/:section',
		[
			'controller' => 'BaseContent',
		]);
	
    $routes->connect('/:section/:action',
		[
			'controller' => 'BaseContent',
		]);
	
    $routes->connect('/:section/:action/:id',
		[
			'controller' => 'BaseContent',
		],
        [
            'pass' => ['id']
        ]);
	
    $routes->connect('/:section/:action/:id/:cid',
		[
			'controller' => 'BaseContent',
		],
        [
            'pass' => ['id', 'cid']
        ]);
	
	$routes->fallbacks('DashedRoute');
});

/**
 * Load all plugin routes.  See the Plugin documentation on
 * how to customize the loading of plugin routes.
 */
Plugin::routes();
