<?php
namespace App\Model\Table;

use App\Model\Entity\Menus;
use Cake\ORM\Query;
use Cake\ORM\RulesChecker;
use Cake\ORM\Table;
use Cake\Validation\Validator;

/**
 * Status Model
 *
 */
class MenusTable extends Table
{

    /**
     * Initialize method
     *
     * @param array $config The configuration for the Table.
     * @return void
     */
    public function initialize(array $config)
    {
        parent::initialize($config);

        $this->table('menus');
        $this->displayField('id');
        $this->primaryKey('id');

      
        $this->belongsTo('Menus', [
            'foreignKey' => 'parent_menu_id'
        ]);
		
        $this->belongsTo('ParentMenus', [
            'foreignKey' => 'parent_menu_id',
			'className' => 'Menus'
        ]);

    }

    /**
     * Default validation rules.
     *
     * @param \Cake\Validation\Validator $validator Validator instance.
     * @return \Cake\Validation\Validator
     */

    public function validationDefault(Validator $validator)
    {
        $validator
            ->add('id', 'valid', ['rule' => 'numeric'])
            ->allowEmpty('id', 'create');

    
        return $validator;
    }

     function searchCategories($pid,$val=null){

           return  $this->find('all')
           ->where(['name  LIKE' => '%'. $val.'%'])
           ->where(['parent_category_id '=> $pid])
           ->order(['ProductCategories.name' => 'ASC']);  
     }


     function findSubSubSubMenus($section){
        $ids=[-1];
        $query = $this->findSubSubMenus($section)->toArray();  
       foreach ($query as $key => $q) {
             array_push( $ids, $q['id']);
        
       }

           return  $this->find('all')
           ->where(['name  LIKE' => '%'. $val.'%'])
           ->where(['parent_category_id IN' => $ids])
           ->order(['ProductCategories.name' => 'ASC']);  
     }


     function findSubSubMenus($id=null){
      $ids=[-1];
       
      $query = $this->find('all', ['conditions' => ['parent_menu_id' => $id]])->toArray();
foreach ($query as $key => $q) {
             array_push( $ids, $q['id']);
        
       }

        
           return  $this->find('all')
                    ->where(['parent_menu_id IN' => $ids]);  
    }
       
        
    function getAllSubCategories(){
        $ids=[-1];
        $query = $this->getAllCategories()->toArray();  
       foreach ($query as $key => $q) {
             array_push( $ids, $q['id']);
        
    }


    return $this->find('all')
          ->where(['parent_category_id IN' => $ids])
          ->order(['ProductCategories.name' => 'ASC']);  
         
    }
    
function searchSubSubCategories($section,$val=null){
        $ids=[-1];
        $query = $this->getAllSubCategories($section)->toArray();  
       foreach ($query as $key => $q) {
             array_push( $ids, $q['id']);
        
       }
           return  $this->find('all')
           ->where(['label  LIKE' => '%'. $val.'%'])
           ->where(['parent_category_id IN' => $ids])
           ->order(['ProductCategories.name' => 'ASC']);  
     }
        
     function getAllSubSubCategories(){
        $ids=[-1];
        $query = $this->getAllSubCategories()->toArray();  
       foreach ($query as $key => $q) {
             array_push( $ids, $q['id']);
        
    }


    return $this->find('all')
          ->where(['parent_category_id IN' => $ids])
          ->order(['ProductCategories.name' => 'ASC']);  
       
  }    

    


         function updateSubCategories($id){
        
           return  $this->find('all')->where(['parent_category_id'=>$id])
                  ->order(['ProductCategories.name' => 'ASC'])
                  ->combine('id', 'name')->toArray();  
  }

    function sectionCategories($id){
        
           return  $this->find('all')->where(['parent_category_id'=>$id])
                  ->order(['ProductCategories.name' => 'ASC']);  
  }

   function getCategories(){
        
           return  $this->find('all')
                  ->order(['ProductCategories.name' => 'ASC'])
                  ->combine('id', 'name')->toArray();  
  }



  function disableCategory($id = null){
    $this->updateAll(['status' => 99], ['id' => $id]);
  }
  
  function enableCategory($id = null){
    $this->updateAll(['status' => 1], ['id' => $id]);
  }
public function getCategoryFromName($category_name = null)
    {
        $category = $this->find('all', ['conditions' => ['name' => $category_name]])->first();
        
        return $category;
    }

    public function getSubCategoriesFromName($category_name = null,$id=null)
    {

        $category = $this->find('All', ['conditions' => ['name' => $category_name,'parent_category_id'=>$id]])->first();
        return $category;
    }
public function getSubCategoriesFromName0($category_name = null)
    {

        $category = $this->find('All', ['conditions' => ['name' => $category_name]])->toArray();
        return count($category);
    }


     public function getListActivesCategories()
    {
        return $this->find('all', ['conditions' => ['parent_category_id' => 0,'status'=>1]]);
    }

      function updateSubMenu($id){
        
           return  $this->find('all')->where(['parent_menu_id'=>$id])
                  ->combine('id', 'name')->toArray();  
  }

}