<?php
namespace App\Model\Table;

use App\Model\Entity\Contents;
use Cake\ORM\Query;
use Cake\ORM\RulesChecker;
use Cake\ORM\Table;
use Cake\Validation\Validator;

/**
 * Status Model
 *
 */
class ContentsTable extends Table
{

    /**
     * Initialize method
     *
     * @param array $config The configuration for the Table.
     * @return void
     */
    public function initialize(array $config)
    {
        parent::initialize($config);

        $this->table('contents');
        $this->displayField('id');
        $this->primaryKey('id');

        $this->belongsTo('Sections', [
            'foreignKey' => 'section_id'
        ]);

         $this->belongsTo('ContentCategories', [
            'foreignKey' => 'post_category_id'
        ]);

          $this->hasMany('ContentImages', [
            'foreignKey' => 'content_id',
            'className' => 'content_images',
            'joinType' => 'RIGHT'        
         ]);
    }

    /**
     * Default validation rules.
     *
     * @param \Cake\Validation\Validator $validator Validator instance.
     * @return \Cake\Validation\Validator
     */

    public function validationDefault(Validator $validator)
    {
        $validator
            ->add('id', 'valid', ['rule' => 'numeric'])
            ->allowEmpty('id', 'create');

        $validator
            ->requirePresence('name', 'create')
            ->notEmpty('name');
        
        $validator
            ->requirePresence('content', 'create')
            ->notEmpty('content');


        return $validator;
    }

     function getContentSectionsById($id){
        
           return  $this->find('all')->where(['section_id'=>$id]);  
  }


     public function getSectionContents($id){
         return $this->find('all')
                    ->contain(['Sections', 'Sections.ParentSections'])
                    ->where([
                             'OR' => [
                            ['Sections.parent_section_id' => $id],
                            ['ParentSections.parent_section_id' => $id]
                            ]]);
       
    }


    public function getContentsTabs($tag=null,$section=null){
       
         return $this->find('all')
                    ->contain(['Sections', 'Tags','ContentImages'])
                    ->where(['Sections.name' => $section,'Tags.name' => $tag,]);
       
    }

}