<?php
namespace App\Model\Table;

use App\Model\Entity\Categories;
use Cake\ORM\Query;
use Cake\ORM\RulesChecker;
use Cake\ORM\Table;
use Cake\Validation\Validator;

/**
 * Status Model
 *
 */
class RoomCategoriesTable extends Table
{

    /**
     * Initialize method
     *
     * @param array $config The configuration for the Table.
     * @return void
     */
    public function initialize(array $config)
    {
        parent::initialize($config);

        $this->table('room_categories');
        $this->displayField('id');
        $this->primaryKey('id');

        $this->hasMany('Rooms', [
            'foreignKey' => 'category_id'       
         ]);

    }

    /**
     * Default validation rules.
     *
     * @param \Cake\Validation\Validator $validator Validator instance.
     * @return \Cake\Validation\Validator
     */

    public function validationDefault(Validator $validator)
    {
        $validator
            ->add('id', 'valid', ['rule' => 'numeric'])
            ->allowEmpty('id', 'create');

        $validator
            ->requirePresence('name', 'create')
            ->notEmpty('name');
        
        $validator
            ->requirePresence('description', 'create')
            ->notEmpty('description');


        return $validator;
    }


     function searchCategories($pid,$val=null){

           return  $this->find('all')
           ->where(['name  LIKE' => '%'. $val.'%'])
           ->where(['parent_category_id '=> $pid])
           ->order(['ProductCategories.name' => 'ASC']);  
     }


     function searchSubCategories($section,$val=null){
        $ids=[-1];
        $query = $this->getAllCategories($section)->toArray();  
       foreach ($query as $key => $q) {
             array_push( $ids, $q['id']);
        
       }

           return  $this->find('all')
           ->where(['name  LIKE' => '%'. $val.'%'])
           ->where(['parent_category_id IN' => $ids])
           ->order(['ProductCategories.name' => 'ASC']);  
     }
        
        function getAllSubCategories(){
        $ids=[-1];
        $query = $this->getAllCategories()->toArray();  
       foreach ($query as $key => $q) {
             array_push( $ids, $q['id']);
        
    }


    return $this->find('all')
          ->where(['parent_category_id IN' => $ids])
          ->order(['ProductCategories.name' => 'ASC']);  
         
    }
    
function searchSubSubCategories($section,$val=null){
        $ids=[-1];
        $query = $this->getAllSubCategories($section)->toArray();  
       foreach ($query as $key => $q) {
             array_push( $ids, $q['id']);
        
       }
           return  $this->find('all')
           ->where(['label  LIKE' => '%'. $val.'%'])
           ->where(['parent_category_id IN' => $ids])
           ->order(['ProductCategories.name' => 'ASC']);  
     }
        
     function getAllSubSubCategories(){
        $ids=[-1];
        $query = $this->getAllSubCategories()->toArray();  
       foreach ($query as $key => $q) {
             array_push( $ids, $q['id']);
        
    }


    return $this->find('all')
          ->where(['parent_category_id IN' => $ids])
          ->order(['ProductCategories.name' => 'ASC']);  
       
  }    

        function getAllCategories($section=null){
        if(!is_null($section)){
         $id = $this->find('all', ['conditions' => ['name' => $section]])->first()->id;
         }else{
           $id =0;  
         }
           return  $this->find('all')
                    ->where(['parent_category_id '=> $id])
                    ->order(['ProductCategories.name' => 'ASC']);  
    }


         function updateSubCategories($id){
        
           return  $this->find('all')->where(['parent_category_id'=>$id])
                  ->order(['ProductCategories.name' => 'ASC'])
                  ->combine('id', 'name')->toArray();  
  }

    function sectionCategories($id){
        
           return  $this->find('all')->where(['parent_category_id'=>$id])
                  ->order(['ProductCategories.name' => 'ASC']);  
  }

   function getCategories(){
        
           return  $this->find('all')
                  ->order(['ProductCategories.name' => 'ASC'])
                  ->combine('id', 'name')->toArray();  
  }



  function disableCategory($id = null){
    $this->updateAll(['status' => 99], ['id' => $id]);
  }
  
  function enableCategory($id = null){
    $this->updateAll(['status' => 1], ['id' => $id]);
  }
public function getCategoryFromName($category_name = null)
    {
        $category = $this->find('all', ['conditions' => ['name' => $category_name]])->first();
        
        return $category;
    }

    public function getSubCategoriesFromName($category_name = null,$id=null)
    {

        $category = $this->find('All', ['conditions' => ['name' => $category_name,'parent_category_id'=>$id]])->first();
        return $category;
    }
public function getSubCategoriesFromName0($category_name = null)
    {

        $category = $this->find('All', ['conditions' => ['name' => $category_name]])->toArray();
        return count($category);
    }


     public function getListActivesCategories()
    {
        return $this->find('all', ['conditions' => ['parent_category_id' => 0,'status'=>1]]);
    }
}
