<?php
/**
 * CakePHP(tm) : Rapid Development Framework (https://cakephp.org)
 * Copyright (c) Cake Software Foundation, Inc. (https://cakefoundation.org)
 *
 * Licensed under The MIT License
 * For full copyright and license information, please see the LICENSE.txt
 * Redistributions of files must retain the above copyright notice.
 *
 * @copyright Copyright (c) Cake Software Foundation, Inc. (https://cakefoundation.org)
 * @link      https://cakephp.org CakePHP(tm) Project
 * @since     0.2.9
 * @license   https://opensource.org/licenses/mit-license.php MIT License
 */
namespace App\Controller;

use Cake\Controller\Controller;
use Cake\Event\Event;
use cake\ORM\TableRegistry;
use Cake\Utility\Inflector;
use Cake\Core\Configure;

/**
 * Application Controller
 *
 * Add your application-wide methods in the class below, your controllers
 * will inherit them.
 *
 * @link https://book.cakephp.org/3.0/en/controllers.html#the-app-controller
 */
class AppController extends Controller
{

    /**
     * Initialization hook method.
     *
     * Use this method to add common initialization code like loading components.
     *
     * e.g. `$this->loadComponent('Security');`
     *
     * @return void
     */
    public function initialize()
    {

        parent::initialize();
        
        $this->loadModel('Contents');
        $this->loadModel('Products');
        $this->loadModel('Menus');
        $this->loadModel('Categories');
        $this->loadModel('ContentImages');
        $this->loadModel('ProductImages');
        $this->loadModel('ProductCategories');
        $this->loadModel('ProImages');
        $this->loadModel('AppSettings');
        $this->loadModel('PageContents');
        $this->loadModel('PageProducts');
         $this->loadModel('Banners');
        $this->loadModel('SectionBannerAssoc');
        $this->loadModel('Users');
        
        $this->loadComponent('RequestHandler');
        $this->loadComponent('Flash');        
        


       $this->loadComponent('Auth', [
            'authorize'=> 'Controller',
            'authenticate' => [
                'Form' => [
                    'fields' => [
                    'username' => 'email',
                    'password' => 'password'
                    ]
                    , 'userModel' => 'Users'
                ]
            ],
                'loginAction' => [
                    'controller' => 'Users',
                    'action' => 'login'
                 ],
                 'loginRedirect' => [
                'controller' => 'Home',
                'action' => 'index'
            ],
            'logoutAction' => [
                'controller' => 'Users',
                'action' => 'login'
            ],
              // If unauthorized, return them to page they were just on
                'unauthorizedRedirect' => $this->referer()
]);
// Allow the display action so our PagesController

// continues to work. Also enable the read only actions.
        /*
         * Enable the following components for recommended CakePHP security settings.
         * see https://book.cakephp.org/3.0/en/controllers/components/security.html
         */
        //$this->loadComponent('Security');
        //$this->loadComponent('Csrf');
    
        /*
         * Enable the following components for recommended CakePHP security settings.
         * see https://book.cakephp.org/3.0/en/controllers/components/security.html
         */
        //$this->loadComponent('Security');
        //$this->loadComponent('Csrf');
    }

    public function isAuthorized($user) {
        $action = $this->request->params['action'];

        return true;
    }

    public function slugController(){
         $slug=null;
        if(!empty($this->request->url)){
         $urlArray = explode("/", $this->request->url);
         $slug=$urlArray[0];
         }
         return $slug;

    }
     public function slugSubController(){
         $slugsub=null;
        if(!empty($this->request->url)){
         $urlArray = explode("/", $this->request->url);
         if(isset($urlArray[1])){
            if($urlArray[1]=="sub")
               $slugsub=$urlArray[2];
          }
         }
         return $slugsub;

    }

     public function beforeRender(Event $event)
    {
      $this->getMenu();
    
     $slug= $this->slugController();
       //   debug( $slug);exit;
    $mmenu=TableRegistry::get('Menus')->find('All')->where(["slug"=>Inflector::slug($slug)])->first();

    $slugsub= $this->slugSubController();


     if($slugsub!==null){
    $submmenu=TableRegistry::get('Menus')->find('All')->where(["slug"=>Inflector::slug($slugsub)])->first();
     $menuitemid=$submmenu->id;
     $menuitemname =$mmenu->name.' > '.$submmenu->name;
       }else{ if(isset($mmenu->id)){
         $menuitemid=$mmenu->id;
         $menuitemname =$mmenu->name;
     }
       }

       
    

        $this->set(compact('menuitemname','menuitemid','slug','slugsub'));
    }
    
    
 public function getMenu(){
        $menus=[];
            
            $mainmenus = TableRegistry::get('Menus')->find('All')->where(["parent_menu_id"=>0,"status"=>1]);
            foreach ($mainmenus as $menu) {
                $submenu=[];
                 
                  
                  $subob = TableRegistry::get('Menus')->find('All')->where(["parent_menu_id"=>$menu->id,"status"=>1]);
             
              if(!is_null($subob)){
                 foreach($subob as $sub){
                     array_push($submenu,[$sub->id,$sub->slug,$sub->name]);

                 }
                 
                  }
                array_push($menus, [[$menu->id,$menu->slug,$menu->name],$submenu]);
            }
            $this->set(compact('menus'));
     }
     
     
     
  
 public function uploadFiles($folder, $file, $itemId = null) {
        // setup dir names absolute and relative
        $folder_url = WWW_ROOT.$folder;
        $rel_url = $folder;
        
        // create the folder if it does not exist
        if(!is_dir($folder_url)) {
            mkdir($folder_url);
        }
            
        // if itemId is set create an item folder
        if($itemId) {
            // set new absolute folder
            $folder_url = WWW_ROOT.$folder.'/'.$itemId; 
            // set new relative folder
            $rel_url = $folder.'/'.$itemId;
            // create directory
            if(!is_dir($folder_url)) {
                mkdir($folder_url);
            }
        }
        
        // list of permitted file types : jpg, jpeg, png, txt, doc, docs, pdf, ppt, pptx, xls, xlsx
        $permitted = Configure::read('SUPPORTED_EXTENSIONS');
        $result=[];
        
        // replace spaces with underscores
        $filename = str_replace(' ', '_', $file['name']);
        // assume filetype is false
        $typeOK = false;
        // check filetype is ok
        foreach($permitted as $type) {
            if($type == $file['type']) {
                $typeOK = true;
                break;
            }
        }
        
        // if file type ok upload the file
        if($typeOK) {
            // switch based on error code
            switch($file['error']) {
                case 0:
                    // create unique filename and upload file
                    ini_set('date.timezone', 'Europe/London');
                    $now = date('Y-m-d-His');
                    $full_url = $folder_url.'/'.$now.$filename;
                    $url = $rel_url.'/'.$now.$filename;
                
                    $success = move_uploaded_file($file['tmp_name'], $url);
                                        // if upload was successful
                    if($success) {
                        // save the url of the file
                        $result['urls'][] = $url;
                        $result['file_type'][] = $file['type'];
                        $result['name'][] = $file['name'];
                        $result['size'][] = $file['size'];
                        $result['file_path'][] = $url;
                    } else {
                        $result['errors'][] = "Error uploaded $filename. Please try again.";
                    }
                    break;
                case 3:
                    // an error occured
                    $result['errors'][] = "Error uploading $filename. Please try again.";
                    break;
                default:
                    // an error occured
                    $result['errors'][] = "System error uploading $filename. Contact webmaster.";
                    break;
            }
        } elseif($file['error'] == 4) {
            // no file was selected for upload
            $result['nofiles'][] = "No file Selected";
        } else {
            // unacceptable file type
            $result['errors'][] = "$filename cannot be uploaded. Acceptable file types: gif, jpg, png.";
        }
        
        return $result;
    } 
    
    
    
    public function uploadImage($folder, $file, $itemId = null, $uploadType=null, $compress = true) {
        // setup dir names absolute and relative
        $folder_url = WWW_ROOT.$folder;
        $rel_url = $folder;
        
        // create the folder if it does not exist
        if(!is_dir($folder_url)) {
            mkdir($folder_url);
        }
            
        // if itemId is set create an item folder
        if($itemId) {
            // set new absolute folder
            $folder_url = WWW_ROOT.$folder.'/'.$itemId; 
            // set new relative folder
            $rel_url = $folder.'/'.$itemId;
            // create directory
            if(!is_dir($folder_url)) {
                mkdir($folder_url);
            }
        }
        
        // list of permitted file types : pictures and vidoes
        $permitted = array('image/jpeg','image/pjpeg','image/png');
        if($uploadType == 3){
            array_push($permitted, 'application/pdf');
        }
        $result = array();
        
        // replace spaces with underscores
        $filename = str_replace(' ', '_', $file['name']);
        // assume filetype is false


        $typeOK = false;
        // check filetype is ok
        foreach($permitted as $type) {
            if($type == $file['type']) {
                $typeOK = true;
                break;
            }
        }
        

        if (in_array($file['type'], array('image/jpeg','image/pjpeg')))
            $source = imagecreatefromjpeg($file['tmp_name']); 
        else if(in_array($file['type'],  array('image/png')))
            $source = imagecreatefrompng($file['tmp_name']);

        // if file type ok upload the file
        if($typeOK) {
            // switch based on error code
            switch($file['error']) {
                case 0:
                    // create unique filename and upload file
                    ini_set('date.timezone', 'Europe/London');
                    $now = date('Y-m-d-His');
                    $full_url = $folder_url.'/'.$now.$filename;
                    $url = $rel_url.'/'.$now.$filename;
                    $thumb_url = $rel_url.'/thumb_'.$now.$filename;
                    
                    // upload the image right away is the size is less than 50kb
                    
                    if($file['size'] < 50000 || $compress == false){
                        
                        $success = move_uploaded_file($file['tmp_name'], $url); 
                       
                    }
                   else{
                    
                        // resize
                        list($width,  $height) = getimagesize($file['tmp_name']);
                        $aspectRatio = $height / $width;
                        $newHeight = $height;
                        $newWidth = $width;
                        
                        if($aspectRatio == 0.75){
                            $newWidth = 800;
                            $newHeight = 600;
                        }
                        else if($aspectRatio < 0.75){
                            if($width >= 800) {
                                $newRatio = $width / 800;
                                $newWidth = 800;
                                $newHeight = $height / $newRatio;
                            }
                        }
                        else if($aspectRatio > 0.75){
                            if($height >= 600) {
                                $newRatio = $height / 600;
                                $newHeight = 600;
                                $newWidth =  $width / $newRatio;
                            }
                        }

                    

                        $thumb = imagecreatetruecolor($newWidth, $newHeight);

                        imagecopyresized($thumb,  $source, 0,  0,  0,  0,  $newWidth,  $newHeight,  $width,  $height);

                        // save resized with compression
                        if (in_array($file['type'], array('image/jpeg','image/pjpeg'))){
                            $success = imagejpeg($thumb, $url, 75);                        
                    

                        }else if(in_array($file['type'],  array('image/png'))){
                         //make image   transpanrent
                        imagesavealpha($thumb, true);
                        $color = imagecolorallocatealpha($thumb, 0, 0, 0, 127);
                         imagefill($thumb, 0, 0, $color);

                            $success = imagepng($thumb, $url, 7, PNG_ALL_FILTERS);
                            //create thumbnail image
                     
                        }

                        //free up memory
                        imagedestroy($thumb);
                    }
                    
                    // if upload was successful
                    if($success) {

                        // save the url of the file
                        $result['urls'][] = $url;
                        $result['file_type'][] = $file['type'];
                        $result['name'][] = $file['name'];
                        $result['size'][] = $file['size'];
                        $result['file_path'][] = $url;
                        
                    } else {
                        $result['errors'][] = "Error uploaded $filename. Please try again.";
                    }
                    break;
                case 3:
                    // an error occured
                    $result['errors'][] = "Error uploading $filename. Please try again.";
                    break;
                default:
                    // an error occured
                    $result['errors'][] = "System error uploading $filename. Contact webmaster.";
                    break;
            }
        } elseif($file['error'] == 4) {
            // no file was selected for upload
            $result['nofiles'][] = "No file Selected";
        } else {
            // unacceptable file type
            $result['errors'][] = "$filename cannot be uploaded. Acceptable file types: gif, jpg, png.";
        }
        
        return $result;
    }


}
