<?php

namespace App\Controller;

use App\Controller\AppController;
use cake\ORM\TableRegistry;
use Cake\I18n\Time;
use Cake\Event\Event;
use Cake\Core\Configure;

/**
 * Items Controller
 *
 * @property \App\Model\Table\ItemsTable $Items and AutoSparePartsTable $AutoSpareParts
 */
class FileUploadsController extends AppController {

    public function initialize() {
        parent::initialize();
        
        $this->loadModel('Files');
        
        $this->paginate = [
            'limit' => 50
        ];
    }

    public function beforeRender(Event $event) {
        parent::beforeRender($event);
    }

    public function isAuthorized($user) {
        $action = $this->request->params['action'];

        return true;
    }

    /**
     * Index method
     *
     * @return void
     */
    public function index($slug = null) {
        $conditions = [];
        $pageTitle = 'All';

        if($slug == 'pending'){
            $pageTitle = 'Pending';
            $conditions['Files.status'] = 0;
        }
        else if($slug == 'enabled'){
            $pageTitle = 'Enabled';
            $conditions['Files.status'] = 1;
        }
        else if($slug == 'disabled'){
            $pageTitle = 'Disabled';
            $conditions['Files.status'] = 99;
        }
        else if($slug == 'edited'){
            $pageTitle = 'Edited';
            $conditions['Files.status'] = 2;
        }

        $listings = $this->Files->find('all')->where($conditions)->order(['Files.date_created' => 'DESC']);
        $listings = $this->paginate($listings);

        $this->set(compact('pageTitle', 'listings'));
    }

    public function add() {
        $fileupload = $this->Files->newEntity();  

        $pageTitle = 'Add File';

        if ($this->request->is(['post'])) {
            $file_field = 'file1';

            if(isset($this->request->data[$file_field])){
                $fileOK = $this->uploadFiles(Configure::read('IMAGE_PREPATH'), $this->request->data[$file_field], null, null, false);
                
                if(array_key_exists('urls', $fileOK)) {
                    $this->request->data['file_path'] = substr($fileOK['file_path'][0],Configure::read('IMAGE_PRELENGTH'),strlen($fileOK['file_path'][0]));
                    $this->request->data['file_name'] = $this->request->data['file1']['name'];
                    $this->request->data['file_type'] = $this->request->data['file1']['type'];
                    $this->request->data['file_size'] = $this->request->data['file1']['size'];
                    
                    $fileupload = $this->Files->patchEntity($fileupload, $this->request->data);
                    if ($this->Files->save($fileupload)) {
                        $this->Flash->success(__('Files added successfully.'));
                        return $this->redirect(['action' => 'index', 'pending']);
                    } else {
                        $this->Flash->error(__('The file could not be save. Try again'));
                    }
                }
                else if(array_key_exists('errors', $fileOK)){
                    $this->Flash->error(__($fileOK['error'][0]));
                }
                else {
                    $this->Flash->error(__('The file could not be save. Try again'));
                }
            }
            
        }        
        $this->set(compact('pageTitle','fileupload', 'cmscatlist','sectionlist'));
    }

    public function edit($id) {

        $fileupload = $this->Files->get($id);  
        $pageTitle = 'Edit File';

        if ($this->request->is(['post', 'put', 'patch'])) {
            $file_field = 'file1';
            $valid = true;
            if(isset($this->request->data[$file_field])){
                $fileOK = $this->uploadFiles(Configure::read('IMAGE_PREPATH'), $this->request->data[$file_field], null, null, false);
                
                if(array_key_exists('urls', $fileOK)) {
                    $this->request->data['file_path'] = substr($fileOK['file_path'][0],Configure::read('IMAGE_PRELENGTH'),strlen($fileOK['file_path'][0]));
                    $this->request->data['file_name'] = $this->request->data['file1']['name'];
                    $this->request->data['file_type'] = $this->request->data['file1']['type'];
                    $this->request->data['file_size'] = $this->request->data['file1']['size'];
                }
                else if(array_key_exists('errors', $fileOK)){
                    $this->Flash->error(__($fileOK['error'][0]));
                    $valid = false;
                }
            }
    
            if($valid) {
                $this->request->data['status'] = 2;                    
                $fileupload = $this->Files->patchEntity($fileupload, $this->request->data);

                if ($this->Files->save($fileupload)) {
                    $this->Flash->success(__('Files updated successfully.'));
                    return $this->redirect(['action' => 'index', 'edited']);
                } else {
                    $this->Flash->error(__('The file could not be updated. Try again'));
                }
            }
        }        
        $this->set(compact('pageTitle','fileupload', 'cmscatlist','sectionlist'));   
    }

    public function enable($id=null)
    {
        $this->viewBuilder()->layout(false);
        $fileupload = $this->Files->get($id);

        $this->request->data['status'] = 1;
        $fileupload = $this->Files->patchEntity($fileupload, $this->request->data);
        
        if ($this->Files->save($fileupload)) {
            $this->Flash->success(__('file Enabled'));
        } else {
            $this->Flash->error(__('Error Occurred'));
        }
        
        return $this->redirect($this->referer());
    }

    public function disable($id=null)
    {
        $this->viewBuilder()->layout(false);
        $fileupload = $this->Files->get($id);
        
        $this->request->data['status'] =99;
        $fileupload = $this->Files->patchEntity($fileupload, $this->request->data);
        
        if ($this->Files->save($fileupload)) {
            $this->Flash->success(__('file Disabled'));
        } else {
            $this->Flash->error(__('Error Occurred'));
        }
        
        return $this->redirect($this->referer());
    }
}