<?php
namespace App\Model\Table;

use Cake\ORM\Query;
use Cake\ORM\RulesChecker;
use Cake\ORM\Table;
use Cake\Validation\Validator;

/**
 * ProductLines Model
 *
 * @property \App\Model\Table\CategoriesTable|\Cake\ORM\Association\BelongsTo $Categories
 * @property \App\Model\Table\ProductBrandsTable|\Cake\ORM\Association\BelongsTo $ProductBrands
 * @property \App\Model\Table\ProductsTable|\Cake\ORM\Association\HasMany $Products
 * @property \App\Model\Table\SalesOrderLinesTable|\Cake\ORM\Association\HasMany $SalesOrderLines
 *
 * @method \App\Model\Entity\ProductLine get($primaryKey, $options = [])
 * @method \App\Model\Entity\ProductLine newEntity($data = null, array $options = [])
 * @method \App\Model\Entity\ProductLine[] newEntities(array $data, array $options = [])
 * @method \App\Model\Entity\ProductLine|bool save(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\ProductLine patchEntity(\Cake\Datasource\EntityInterface $entity, array $data, array $options = [])
 * @method \App\Model\Entity\ProductLine[] patchEntities($entities, array $data, array $options = [])
 * @method \App\Model\Entity\ProductLine findOrCreate($search, callable $callback = null, $options = [])
 */
class ProductLinesTable extends Table
{

    /**
     * Initialize method
     *
     * @param array $config The configuration for the Table.
     * @return void
     */
    public function initialize(array $config)
    {
        parent::initialize($config);

        $this->setTable('product_lines');
        $this->setDisplayField('name');
        $this->setPrimaryKey('id');

        $this->belongsTo('Categories', [
            'foreignKey' => 'category_id'
        ]);
        $this->belongsTo('ProductBrands', [
            'foreignKey' => 'product_brand_id'
        ]);
        $this->hasMany('Products', [
            'foreignKey' => 'product_line_id'
        ]);
        $this->hasMany('SalesOrderLines', [
            'foreignKey' => 'product_line_id'
        ]);
    }

    /**
     * Default validation rules.
     *
     * @param \Cake\Validation\Validator $validator Validator instance.
     * @return \Cake\Validation\Validator
     */
    public function validationDefault(Validator $validator)
    {
        $validator
            ->integer('id')
            ->allowEmpty('id', 'create');

        $validator
            ->scalar('name')
            ->maxLength('name', 255)
            ->allowEmpty('name');

        $validator
            ->scalar('description')
            ->allowEmpty('description');

        $validator
            ->integer('quantity')
            ->allowEmpty('quantity');

        $validator
            ->integer('viewed')
            ->allowEmpty('viewed');

        $validator
            ->dateTime('featured_start_date')
            ->allowEmpty('featured_start_date');

        $validator
            ->dateTime('featured_end_date')
            ->allowEmpty('featured_end_date');

        $validator
            ->integer('status')
            ->allowEmpty('status');

        $validator
            ->decimal('price')
            ->allowEmpty('price');

        $validator
            ->integer('featured')
            ->allowEmpty('featured');

        $validator
            ->scalar('product_code')
            ->maxLength('product_code', 255)
            ->allowEmpty('product_code');

        return $validator;
    }

    /**
     * Returns a rules checker object that will be used for validating
     * application integrity.
     *
     * @param \Cake\ORM\RulesChecker $rules The rules object to be modified.
     * @return \Cake\ORM\RulesChecker
     */
    public function buildRules(RulesChecker $rules)
    {
        $rules->add($rules->existsIn(['category_id'], 'Categories'));
        $rules->add($rules->existsIn(['product_brand_id'], 'ProductBrands'));

        return $rules;
    }
}
