<?php
namespace App\Model\Table;

use Cake\ORM\Query;
use Cake\ORM\RulesChecker;
use Cake\ORM\Table;
use Cake\Validation\Validator;

/**
 * Products Model
 *
 * @property \App\Model\Table\ProductLinesTable|\Cake\ORM\Association\BelongsTo $ProductLines
 * @property \App\Model\Table\ProductColorsTable|\Cake\ORM\Association\BelongsTo $ProductColors
 * @property \App\Model\Table\ProductMakesTable|\Cake\ORM\Association\BelongsTo $ProductMakes
 * @property \App\Model\Table\ProductModelsTable|\Cake\ORM\Association\BelongsTo $ProductModels
 * @property \App\Model\Table\ProductVolumesTable|\Cake\ORM\Association\BelongsTo $ProductVolumes
 * @property \App\Model\Table\ProductSizesTable|\Cake\ORM\Association\BelongsTo $ProductSizes
 * @property \App\Model\Table\ProductAgesTable|\Cake\ORM\Association\BelongsTo $ProductAges
 * @property \App\Model\Table\OrderLinesTable|\Cake\ORM\Association\HasMany $OrderLines
 * @property \App\Model\Table\PageProductsTable|\Cake\ORM\Association\HasMany $PageProducts
 * @property \App\Model\Table\ProductImagesTable|\Cake\ORM\Association\HasMany $ProductImages
 * @property \App\Model\Table\ProductSettingsTable|\Cake\ORM\Association\HasMany $ProductSettings
 * @property \App\Model\Table\SalesOrderLinesTable|\Cake\ORM\Association\HasMany $SalesOrderLines
 *
 * @method \App\Model\Entity\Product get($primaryKey, $options = [])
 * @method \App\Model\Entity\Product newEntity($data = null, array $options = [])
 * @method \App\Model\Entity\Product[] newEntities(array $data, array $options = [])
 * @method \App\Model\Entity\Product|bool save(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\Product patchEntity(\Cake\Datasource\EntityInterface $entity, array $data, array $options = [])
 * @method \App\Model\Entity\Product[] patchEntities($entities, array $data, array $options = [])
 * @method \App\Model\Entity\Product findOrCreate($search, callable $callback = null, $options = [])
 */
class ProductsTable extends Table
{

    /**
     * Initialize method
     *
     * @param array $config The configuration for the Table.
     * @return void
     */
    public function initialize(array $config)
    {
        parent::initialize($config);

        $this->setTable('products');
        $this->setDisplayField('name');
        $this->setPrimaryKey('id');

        $this->belongsTo('ProductLines', [
            'foreignKey' => 'product_line_id'
        ]);
        $this->belongsTo('ProductColors', [
            'foreignKey' => 'product_color_id'
        ]);
        $this->belongsTo('ProductMakes', [
            'foreignKey' => 'product_make_id'
        ]);
        $this->belongsTo('ProductModels', [
            'foreignKey' => 'product_model_id'
        ]);
        $this->belongsTo('ProductVolumes', [
            'foreignKey' => 'product_volume_id'
        ]);
        $this->belongsTo('ProductSizes', [
            'foreignKey' => 'product_size_id'
        ]);
        $this->belongsTo('ProductAges', [
            'foreignKey' => 'product_age_id'
        ]);
        $this->hasMany('OrderLines', [
            'foreignKey' => 'product_id'
        ]);
        $this->hasMany('PageProducts', [
            'foreignKey' => 'product_id'
        ]);
        $this->hasMany('ProductImages', [
            'foreignKey' => 'product_id'
        ]);
        $this->hasMany('ProductSettings', [
            'foreignKey' => 'product_id'
        ]);
        $this->hasMany('SalesOrderLines', [
            'foreignKey' => 'product_id'
        ]);
    }

    /**
     * Default validation rules.
     *
     * @param \Cake\Validation\Validator $validator Validator instance.
     * @return \Cake\Validation\Validator
     */
    public function validationDefault(Validator $validator)
    {
        $validator
            ->integer('id')
            ->allowEmpty('id', 'create');

        $validator
            ->scalar('name')
            ->maxLength('name', 255)
            ->requirePresence('name', 'create')
            ->notEmpty('name');

        $validator
            ->scalar('bar_code')
            ->maxLength('bar_code', 255)
            ->requirePresence('bar_code', 'create')
            ->notEmpty('bar_code');

        $validator
            ->decimal('price')
            ->allowEmpty('price');

        $validator
            ->scalar('description')
            ->allowEmpty('description');

        $validator
            ->integer('featured')
            ->requirePresence('featured', 'create')
            ->notEmpty('featured');

        $validator
            ->dateTime('featured_start_date')
            ->requirePresence('featured_start_date', 'create')
            ->notEmpty('featured_start_date');

        $validator
            ->dateTime('featured_end_date')
            ->requirePresence('featured_end_date', 'create')
            ->notEmpty('featured_end_date');

        $validator
            ->integer('viewed')
            ->allowEmpty('viewed');

        $validator
            ->dateTime('date_created')
            ->allowEmpty('date_created');

        $validator
            ->integer('status')
            ->allowEmpty('status');

        return $validator;
    }

    /**
     * Returns a rules checker object that will be used for validating
     * application integrity.
     *
     * @param \Cake\ORM\RulesChecker $rules The rules object to be modified.
     * @return \Cake\ORM\RulesChecker
     */
    public function buildRules(RulesChecker $rules)
    {
        $rules->add($rules->existsIn(['product_line_id'], 'ProductLines'));
        $rules->add($rules->existsIn(['product_color_id'], 'ProductColors'));
        $rules->add($rules->existsIn(['product_make_id'], 'ProductMakes'));
        $rules->add($rules->existsIn(['product_model_id'], 'ProductModels'));
        $rules->add($rules->existsIn(['product_volume_id'], 'ProductVolumes'));
        $rules->add($rules->existsIn(['product_size_id'], 'ProductSizes'));
        $rules->add($rules->existsIn(['product_age_id'], 'ProductAges'));

        return $rules;
    }
}
