<?php
/**
 * Routes configuration
 *
 * In this file, you set up routes to your controllers and their actions.
 * Routes are very important mechanism that allows you to freely connect
 * different URLs to chosen controllers and their actions (functions).
 *
 * CakePHP(tm) : Rapid Development Framework (https://cakephp.org)
 * Copyright (c) Cake Software Foundation, Inc. (https://cakefoundation.org)
 *
 * Licensed under The MIT License
 * For full copyright and license information, please see the LICENSE.txt
 * Redistributions of files must retain the above copyright notice.
 *
 * @copyright     Copyright (c) Cake Software Foundation, Inc. (https://cakefoundation.org)
 * @link          https://cakephp.org CakePHP(tm) Project
 * @license       https://opensource.org/licenses/mit-license.php MIT License
 */
use Cake\Http\Middleware\CsrfProtectionMiddleware;
use Cake\Routing\RouteBuilder;
use Cake\Routing\Router;
use Cake\Routing\Route\DashedRoute;

/**
 * The default class to use for all routes
 *
 * The following route classes are supplied with CakePHP and are appropriate
 * to set as the default:
 *
 * - Route
 * - InflectedRoute
 * - DashedRoute
 *
 * If no call is made to `Router::defaultRouteClass()`, the class used is
 * `Route` (`Cake\Routing\Route\Route`)
 *
 * Note that `Route` does not do any inflections on URLs which will result in
 * inconsistently cased URLs when used with `:plugin`, `:controller` and
 * `:action` markers.
 *
 * Cache: Routes are cached to improve performance, check the RoutingMiddleware
 * constructor in your `src/Application.php` file to change this behavior.
 *
 */
Router::defaultRouteClass(DashedRoute::class);

Router::scope('/', function (RouteBuilder $routes) {
    // Register scoped middleware for in scopes.
    $routes->registerMiddleware('csrf', new CsrfProtectionMiddleware([
        'httpOnly' => true
    ]));

    /**
     * Apply a middleware to the current route scope.
     * Requires middleware to be registered via `Application::routes()` with `registerMiddleware()`
     */
    $routes->applyMiddleware('csrf');

    /**
     * Here, we are connecting '/' (base path) to a controller called 'Pages',
     * its action called 'display', and we pass a param to select the view file
     * to use (in this case, src/Template/Pages/home.ctp)...
     */
    $routes->connect('/', ['controller' => 'Home', 'action' => 'index']);
	
    /**
	 * Routing for About Us
	 * 
	 * 1. Main menu
	 * 2. Sub menu
	 * 3. Detailed view of a selected record
	 */
    $routes->connect('/about-us', 
		[
			'controller' => 'AboutUs',
		]);
        
    $routes->connect('/about-us/:subsection', 
		[
			'controller' => 'AboutUs',
			'action' => 'subMenu',
		],
		[
			'pass' => ['subsection']
		]);
        
    $routes->connect('/about-us/details/:id', 
		[
			'controller' => 'AboutUs',
			'action' => 'details',
		],
        [
            'pass' => ['id']
        ]);
	
    /**
	 * Routing for Services
	 * 
	 * 1. Main menu
	 * 2. Sub menu
	 * 3. Detailed view of a selected record
	 */
	 /*
	  * This is no longer needed as services will be 
	  * rendered by the base controller
    $routes->connect('/services', 
		[
			'controller' => 'Services',
		]);
        
    $routes->connect('/services/:subsection', 
		[
			'controller' => 'Services',
			'action' => 'subMenu',
		],
		[
			'pass' => ['subsection']
		]);
        
    $routes->connect('/services/details/:id', 
		[
			'controller' => 'Services',
			'action' => 'details',
		],
        [
            'pass' => ['id']
        ]);
	*/
	
    /**
	 * Routing for the gallery
	 * Route for gallery home and album 
	 */
    $routes->connect('/gallery', 
		[
			'controller' => 'Gallery',
		]);
        
    $routes->connect('/gallery/details/:id', 
		[
			'controller' => 'Gallery',
			'action' => 'details',
		],
        [
            'pass' => ['id']
        ]);
	
    /**
	 * Routing for the contact us
	 * Route for contact us
	 */
    $routes->connect('/contact-us', 
		[
			'controller' => 'ContactUs',
		]);
	
    /**
	 * Set the fallback controller to contents, when no matching controller is found
	 * from the matching the route
	 * Basic contents supports
	 * 1. Main menu
	 * 2. Sub menu
	 * 3. Detailed view of a selected record
	 */
    $routes->connect('/:section', 
		[
			'controller' => 'Content',
		]);
        
    $routes->connect('/:section/:subsection', 
		[
			'controller' => 'Content',
			'action' => 'subsection',
		]);
        
    $routes->connect('/:section/details/:id', 
		[
			'controller' => 'Content',
			'action' => 'details',
		],
        [
            'pass' => ['id']
        ]);
        
    /**
     * Connect catchall routes for all controllers.
     *
     * Using the argument `DashedRoute`, the `fallbacks` method is a shortcut for
     *
     * ```
     * $routes->connect('/:controller', ['action' => 'index'], ['routeClass' => 'DashedRoute']);
     * $routes->connect('/:controller/:action/*', [], ['routeClass' => 'DashedRoute']);
     * ```
     *
     * Any route class can be used with this method, such as:
     * - DashedRoute
     * - InflectedRoute
     * - Route
     * - Or your own route class
     *
     * You can remove these routes once you've connected the
     * routes you want in your application.
     */
    $routes->fallbacks(DashedRoute::class);
});

/**
 * If you need a different set of middleware or none at all,
 * open new scope and define routes there.
 *
 * ```
 * Router::scope('/api', function (RouteBuilder $routes) {
 *     // No $routes->applyMiddleware() here.
 *     // Connect API actions here.
 * });
 * ```
 */
