<?php
/**
 * CakePHP(tm) : Rapid Development Framework (https://cakephp.org)
 * Copyright (c) Cake Software Foundation, Inc. (https://cakefoundation.org)
 *
 * Licensed under The MIT License
 * For full copyright and license information, please see the LICENSE.txt
 * Redistributions of files must retain the above copyright notice.
 *
 * @copyright Copyright (c) Cake Software Foundation, Inc. (https://cakefoundation.org)
 * @link      https://cakephp.org CakePHP(tm) Project
 * @since     0.2.9
 * @license   https://opensource.org/licenses/mit-license.php MIT License
 */
namespace App\Controller;

use Cake\Controller\Controller;
use Cake\Event\Event;
use Cake\ORM\TableRegistry;
use Cake\Utility\Inflector;
use Cake\Mailer\Email;

/**
 * Application Controller
 *
 * Add your application-wide methods in the class below, your controllers
 * will inherit them.
 *
 * @link https://book.cakephp.org/3.0/en/controllers.html#the-app-controller
 */
class AppController extends Controller
{

	var $appSettings = [];
	
    /**
     * Initialization hook method.
     *
     * Use this method to add common initialization code like loading components.
     *
     * e.g. `$this->loadComponent('Security');`
     *
     * @return void
     */
    public function initialize()
    {
        parent::initialize();

        $this->loadComponent('RequestHandler', [
            'enableBeforeRedirect' => false,
        ]);
        $this->loadComponent('Flash');

        /*
         * Enable the following component for recommended CakePHP security settings.
         * see https://book.cakephp.org/3.0/en/controllers/components/security.html
         */
        //$this->loadComponent('Security');
    }
	
	public function beforeRender(Event $event)
    {
		$this->getMenu();
		
		$this->appSettings = TableRegistry::get('AppSettings')->find('All')->combine("setting_name","setting_value")->toArray();
		$contacts = TableRegistry::get('Contacts')->find('All')->first();
		$this->set(compact('contacts'));
		$this->set('appSettings', $this->appSettings);
    }
	
	public function getMenu(){
		$menus = TableRegistry::get('Menus')->find('all', [
            'contain' => ['ChildMenus'],
            'conditions' => [
                'Menus.parent_menu_id' => 0, 
                'Menus.status' => 1
            ]
        ])->order(['order_value' => 'ASC']);
        
        $footerMenus = TableRegistry::get('Menus')->find('all', [
            'contain' => ['ChildMenus'],
            'conditions' => [
                'Menus.parent_menu_id' => 0, 
                'Menus.status' => 1,
                'Menus.show_on_footer' => 1,
            ]
        ]);
        
		$this->set(compact('menus', 'footerMenus'));
     }
	
	
    /**
	 * Generic method to process all forms.
	 * Save the content into the databse and forward the details to the email specified
	 * entity is the table to save to
	 */
    public function processForm($entity = null, $emailTitle = null, $options = []){
        
        // Just return if there is no entity specified
        if($entity == null) {
            return $this->redirect($this->referer());
        }
        
        $formTable = TableRegistry::get($entity);
        /// TODO:: Check is the table registry retrived the table entity successfully
        
        $formEntity = $formTable->newEntity();
    
        if ($this->request->is('post')) {
            $formEntity = $formTable->patchEntity($formEntity, $this->request->getData());
            
            // Retrieve the default email to send the information to
            $contact = TableRegistry::get('Contacts')->find('All')->first();        
        
            if ($formTable->save($formEntity)) {
                    $title = $emailTitle;
                    
                    // Compile the content for the email
                    $message= "";
                    
                    foreach($options as $key => $value) {
                        $message.= '<b>' . Inflector::humanize($key) . '</b>: ' . $value . '<br/>';
                    }
                    
                    $email = new Email('default');
                    $email->setFrom(isset($options['email']) ? $options['email'] : 'user@server.com')
                        ->setTo($contact->email1)
                        ->setEmailFormat('html')
                        ->setSubject($title)
                        ->send( $message);
              
                $this->Flash->success(__('Form successfully processed'));
            }else{
                $this->Flash->error(__('Error occurred processing the form. Please, try again.'));
            }
        }
    
        return $this->redirect($this->referer());
     }
}
