<?php
/**
 * CakePHP(tm) : Rapid Development Framework (https://cakephp.org)
 * Copyright (c) Cake Software Foundation, Inc. (https://cakefoundation.org)
 *
 * Licensed under The MIT License
 * For full copyright and license information, please see the LICENSE.txt
 * Redistributions of files must retain the above copyright notice.
 *
 * @copyright Copyright (c) Cake Software Foundation, Inc. (https://cakefoundation.org)
 * @link      https://cakephp.org CakePHP(tm) Project
 * @since     0.2.9
 * @license   https://opensource.org/licenses/mit-license.php MIT License
 */
namespace App\Controller;

use Cake\Core\Configure;
use cake\ORM\TableRegistry;
use Cake\Utility\Inflector;
use Cake\Mailer\Email;

/**
 * Static content controller
 *
 * This controller will render views from Template/Home/
 *
 */
class HomeController extends AppController
{
	/**
     * Initialization hook method.
     *
     * Use this method to add common initialization code like loading components.
     *
     * e.g. `$this->loadComponent('Security');`
     *
     * @return void
     */
    public function initialize()
    {
        parent::initialize();

        $this->loadModel('PageContents');
        $this->loadModel('Banners');
        $this->loadModel('Contacts');
        $this->loadModel('Galleries');
		$this->loadModel('Files');
    }
	
    public function index(...$path)
    {
		/** 
		 * Homepage for the one pager site
		 * Lets load the contents for the different sections
		 * 
		 * Contents are stored under different menus, in our order to load them correctly
		 * Selects the different menus under the section and construct a an array with
		 * with the contents saved with the menu as key
		 */

		// Load only enabled menus
		$homeMenus = $this->PageContents->Menus->find('all', [
			'conditions' => [
				'status' => '1'
			]
		])->order([
		    'home_order' => 'ASC'
		]);
		
		// Initialize the content array and populate the contents of each section
		// Filter by only contents that have been marked to show on the hompage
		$viewContents = [];
		
		// Populates sub menus that would be showing as points on the home
		// to redirect to the their home pages
		$viewSubsections = [];
		
		foreach($homeMenus as $menu) {
			$content = $this->PageContents->Contents->find('all', [
				'contain' => [
					'ContentImages', 'PageContents'
				],
				'conditions' => [
					'status' => 1,
					'show_on_home' => 1
				]
			])->matching('PageContents', function ($q) use($menu) {
				return $q->where(['PageContents.menu_id' => $menu->id]);
			})->toArray();

			if(sizeof($content) > 0) {
				$viewContents[$menu->slug] = $content;
			}
			
			$menuContents = $this->PageContents->Menus->find('all', [
			    'contain' => [
			        'ParentMenus'  
			    ],
			    'conditions' => [
			        'Menus.parent_menu_id' => $menu->id,
			        'Menus.status' => 1,
			        'Menus.show_on_home' => 1
			    ]
			])->toArray();

			if(sizeof($menuContents) > 0) {
				$viewSubsections[$menu->slug] = [
				    'section' => $menu,
				    'list' => $menuContents
				];
			}
		}
		
		// Load the banners. Banners are normally loaded at the top of the page.
		// So lets add it to the home section.
		// Append to any section if you want to show as well, could be carousel, etc....
		$banners = $this->Banners->find('all', [
			'conditions' => [
				'status' => 1
			]
		])->toArray();
		
		// Load the contact details
		// We will need this for the contact information of the company
		$contactDetails = $this->Contacts->find('All')->first();
		
		// Load the gallery records
		// Lets get all the pictures
		$galleryDetails = $this->Galleries->find('all', [
			'conditions' => [
				'status' => 1
				
			]
		]);
		
		// Initialize the content array and populate the contents of each section
		$viewAlbums = $this->Galleries->Albums->find('all', [
			'contain' => [
				'Galleries'
			],
			'conditions' => [
				'Albums.status' => 1,
				'Albums.show_on_home' => 1
			]
		])->toArray();

		$filesContent = $this->Files->find('all', [
			'conditions' => [
				'status' => 1,
				'show_on_home'=> 1
			]
		])
		->toArray();
		
		// Process form, Contact us form from the page
		if ($this->request->is('post')) {
			$this->processForm('Feedbacks', 'Customer Feedback', $this->request->getData());
		}
		
		/**
		 * Perform additional task here before sending the values
		 * to be rendered on the view
		 */
		
		$this->set(compact('viewContents', 'banners', 'contactDetails', 'galleryDetails', 'homeMenus', 'viewSubsections', 'viewAlbums','filesContent'));
    }
}
